==> blink-components-0.4.0.tgz: package/.storybook/connected/home.js <==
// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import { Link, Element } from 'react-scroll'
import Icon from 'components/Icon'
import Template from 'components/Template'
import Hero from 'components/Hero'
import Section from 'components/Section'
import Card from 'components/Card'
import PostCard from 'components/PostCard'
import OptIn from 'components/OptIn'
import Carousel from 'components/Carousel'
import theme from './theme'

import { services, navItems, languages, hero, footer, post, copyright } from '../../sample-data'

const HeroAction = () => (
  <div>
    <Link
      className="near-black roboto fw9 tracked ttu -bg-golden ph3 pv2 f5 ph4-l pv3-l f4-l pointer br2"
      to="services"
      smooth
    >
      <span>Tìm hiểu thêm</span>
      <Icon name="fa-angle-right" className="ml2" />
    </Link>
  </div>
)

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={footer}
      copyright={copyright}
      tawkId="5927f86eb3d02e11ecc66f01"
    >
      <Hero
        {...hero}
        action={<HeroAction />}
      />
      <Element name="services">
        <Section
          title="Dịch vụ"
          subtitle="Chúng tôi có thể giúp bạn"
        >
          <div className="flex flex-wrap">
            {services.map(item => (
              <div key={item.title} className="w-100 w-50-m w-25-l pa2">
                <Card key={item.title} item={item} />
              </div>
            ))}
          </div>
        </Section>
      </Element>
      <Section
        title="Công nghệ"
        subtitle="Chúng tôi sử dụng công nghệ tiên tiến, tương thích mọi thiết bị"
      >
        <Carousel
          theme={theme}
          slidesToShow={4}
          items={services}
          renderItem={({ title, image }) => (
            <div key={title} className="ph1">
              <img src={image} alt={title} />
            </div>
          )}
        />
      </Section>
      <Section
        className="-bg-golden"
        title="Bạn cần tư vấn?"
        subtitle="Để lại tên và số điện thoại, chúng tôi sẽ liên lạc lại với bạn ngay lập tức"
        theme={{
          body: 'mw7 center ph2',
        }}
      >
        <OptIn
          requireName
          data={{ isHorizontal: true, callToAction: 'Give Me Now' }}
        />
      </Section>
      <Section
        title="Blog"
        subtitle="Bài viết hữu ích"
        theme={{
          body: 'flex flex-wrap',
        }}
      >
        {[1, 2, 3].map(key => (
          <div key={key} className="w-100 w-third-ns pa3">
            <PostCard
              item={post}
              theme={theme}
            />
          </div>
        ))}
      </Section>
    </Template>
  </ThemeProvider>
)

export default Home

==> blink-components-0.5.4.tgz: package/.storybook/connected/home.js <==
// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import { Link, Element } from 'react-scroll'
import Icon from 'components/Icon'
import Template from 'components/Template'
import HeroWithAction from 'components/HeroWithAction'
import Section from 'components/Section'
import Card from 'components/Card'
import PostCard from 'components/PostCard'
import OptIn from 'components/OptIn'
import Carousel from 'components/Carousel'
import theme from './theme.yml'

import {
  services,
  navItems,
  languages,
  hero,
  footer,
  samplePost,
  copyright,
} from '../../sample-data/connected.yml'

const HeroAction = () => (
  <div>
    <Link
      className="dib near-black roboto fw9 tracked ttu -bg-golden ph3 pv2 f5 ph4-l pv3-l f4-l pointer br2"
      to="services"
      smooth
    >
      <span>Tìm hiểu thêm</span>
      <Icon name="fa-angle-right" className="ml2" />
    </Link>
  </div>
)

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={{
        ...footer,
        items: navItems,
      }}
      copyright={copyright}
    >
      <HeroWithAction
        {...hero}
        action={<HeroAction />}
      />
      <Element name="services">
        <Section
          title="Dịch vụ"
          subtitle="Chúng tôi có thể giúp bạn"
        >
          <div className="flex flex-wrap">
            {services.map(item => (
              <div key={item.title} className="w-100 w-50-m w-25-l pa2">
                <Card key={item.title} item={item} />
              </div>
            ))}
          </div>
        </Section>
      </Element>
      <Section
        title="Công nghệ"
        subtitle="Chúng tôi sử dụng công nghệ tiên tiến, tương thích mọi thiết bị"
      >
        <Carousel
          theme={theme}
          slidesToShow={4}
          items={services}
          renderItem={({ title, image }) => (
            <div key={title} className="ph1">
              <img src={image} alt={title} />
            </div>
          )}
        />
      </Section>
      <Section
        className="-bg-golden"
        title="Bạn cần tư vấn?"
        subtitle="Để lại tên và số điện thoại, chúng tôi sẽ liên lạc lại với bạn ngay lập tức"
        theme={{
          body: 'mw7 center ph2',
        }}
      >
        <OptIn
          requireName
          data={{ isHorizontal: true, callToAction: 'Give Me Now' }}
        />
      </Section>
      <Section
        title="Blog"
        subtitle="Bài viết hữu ích"
        theme={{
          body: 'flex flex-wrap',
        }}
      >
        {[1, 2, 3].map(key => (
          <div key={key} className="w-100 w-third-ns pa3">
            <PostCard
              item={samplePost}
              theme={theme}
            />
          </div>
        ))}
      </Section>
    </Template>
  </ThemeProvider>
)

export default Home
